flutter_tailwind library

Classes

AlignedGridView
A scrollable, 2D array of widgets placed according to the aligned layout.
AnimatedCheckBox
AnimatedRadio<T>
BaseImageFactory
@date 2024/12/27 describe:
ButtonBuilder
CachedNetworkImage
Image widget to show NetworkImage with caching functionality.
CachedNetworkImageProvider
IO implementation of the CachedNetworkImageProvider; the ImageProvider to load network images using a cache.
CallBackBuilder<T>
ChildBuilder<T>
ChildClickBuilder<T>
ChildMkBuilder<T>
ChildrenBuilder<T>
ChildrenSpanBuilder<T>
ClickBuilder<T>
ContainerBuilder
DownloadProgress
Progress of the file that is being downloaded from the originalUrl.
FontSizeResolvers
HBox
Barry @date 9/11/23 describe:
ImageBuilder
ImageLoader
ImageLoaderConfigInterface
配置只复写builder式的构造方法
Input
Barry @date 2024/9/11 describe:
ItemBuilder
MasonryGridView
A scrollable, 2D array of widgets placed according to the masonry layout.
MkBuilder<T>
Barry @date 2024/8/20 describe:
MultiImageStreamCompleter
An ImageStreamCompleter with support for loading multiple images.
QuiltedGridRepeatPattern
Defines how a pattern is repeating.
QuiltedGridTile
A tile for SliverQuiltedGridDelegate.
RadioCallBackBuilder
RebuildFactors
REdgeInsets
REdgeInsetsDirectional
RenderSliverMasonryGrid
A sliver that places multiple box children in a two dimensional arrangement.
RichTextBuilder
RPadding
RSizedBox
ScreenUtil
ScreenUtilInit
SliverAlignedGrid
A sliver that places multiple box children in a two dimensional arrangement.
SliverMasonryGrid
A sliver that places multiple box children in a two dimensional arrangement.
SliverMasonryGridParentData
Parent data structure used by RenderSliverMasonryGrid.
SliverQuiltedGridDelegate
Controls the layout of a quilted grid.
SliverSimpleGridDelegate
Controls the layout of tiles in a some slivers.
SliverSimpleGridDelegateWithFixedCrossAxisCount
Creates grid layouts with a fixed number of tiles in the cross axis.
SliverSimpleGridDelegateWithMaxCrossAxisExtent
Creates grid layouts with tiles that each have a maximum cross-axis extent.
SliverStairedGridDelegate
Controls the layout of tiles in a staired grid.
SliverWovenGridDelegate
Controls the layout of tiles in a woven grid.
StaggeredGrid
A grid which lays out children in a staggered arrangement. Each child can have a different size. Wrap your children with a StaggeredGridTile to specify their size if it's different from a 1x1 tile.
StaggeredGridTile
Represents the size of a StaggeredGrid's tile.
StairedGridTile
A tile of a staired pattern.
StrokeTextBuilder
Tailwind
Barry @date 2024/8/21 describe:
TextBuilder
Text
TextStyleBuilder
TextStyle
WBox
WovenGridTile
A tile of a woven pattern.

Enums

CacheManagerLogLevel
Log levels of the cache manager. Debug shows failed downloads and verbose also shows successful downloads and cache retrievals.
DeviceType

Mixins

AlignmentBuilder
Barry @date 2024/8/20 describe:
AspectRatioBuilder
Barry @date 2024/8/28 describe:
AxisBuilder
Barry @date 2024/9/21 describe:
BlendModeBuilder
Barry @date 7/11/23 describe:
BorderColorBuilder
BorderRadiusBuilder
Barry @date 7/11/23 describe:
BorderWidthBuilder
Barry @date 7/11/23 describe:
BoxFitBuilder
Barry @date 2024/8/19 describe:
BoxShapeBuilder
ButtonIconBuilder
CheckBoxMixin
ClipBuilder
Barry @date 2024/8/20 describe:
ColorBuilder
Barry @date 7/11/23 describe:
CompleteDecoration
Barry @date 2024/8/22 describe:
CompletedTextStyleBuilder
Barry @date 2024/8/19 describe: A bit like Csstailwind or chain programming like ios swift 有点像Csstailwind或者像ios swift的链式编程
ExpandedBuilder
Barry @date 2024/10/15 describe:
FontSizeBuilder
Barry @date 7/11/23 describe:
FontWeightBuilder
GradientBuilder
Barry @date 2024/8/24 describe:
GridViewFeature
IconBuilder
Barry @date 2024/9/13 describe:
ImageProviderBuilderMixin
KeyBuilder
Barry @date 2024/10/24 describe:
LinearFeature
MarginBuilder
Barry @date 2024/8/26 describe:
MaxLineBuilder
Barry @date 7/11/23 describe:
OpacityBuilder
PaddingBuilder
PositionedBuilder
Barry @date 2024/8/26 describe:
RadioMixin
ScrollFeature
SeparatorBuilder
ShadowBuilder
Barry @date 2024/8/24 describe:
SizeBuilder
Barry @date 2024/8/20 describe:
SpacingBuilder
Barry @date 2024/9/21 describe:
StackFeature
StepMixin
SU
TextAlignBuilder
TextBaselineBuilder
TextColorBuilder
TextDirectionBuilder
Barry @date 7/11/23 describe:
TextFeature
TooltipBuilder
@date 9/5/25 describe:
WrapMixin
Barry @date 2024/12/9 describe:

Extensions

AlignmentBuilderExt on T
AspectRatioBuilderExt on T
AxisBuilderExt on T
BlendModeBuilderExt on T
BorderColorBuilderExt on T
BorderRadiusBuilderExt on T
BorderRadiusExtension on BorderRadius
BorderWidthBuilderExt on T
BoxConstraintsExtension on BoxConstraints
BoxDecorationBuilderColorExt on Color
BoxDecorationBuilderExt on _BoxDecorationBuilder
BoxFitBuilderExt on T
BoxShapeBuilderExt on T
ButtonIconBuilderExt on T
ButtonStringExt on String?
CheckBoxMixinExt on T
ClickListenerExt on Widget
ClipBuilderExt on T
ColorBuilderExt on T
ColorOpacityExt on T
ColorOptionalOpacityExt on Color?
Barry @date 2024/9/4 describe:
CustomSp on num
EdgeInsetsExtension on EdgeInsets
ExpandedBuilderExt on T
FontSizeBuilderExt on T
FontWeightBuilderExt on T
GradientBuilderExt on T
GridViewFeatureExt on T
IconBuilderExt on T
IconStringBuilder on IconData
IconWidgetBuilderExt on T
ImageBuilderExt on T
ImageProviderBuilderExt on T
KeyBuilderMixin on T
LinearFeatureExt on T
MarginBuilderBuilderExt on T
MaxLineBuilderExt on T
MkBuilderExt on T
OpacityBuilderExt on T
PaddingBuilderExt on T
PositionedBuilderBuilderExt on T
RadioMixinExt on T
RadiusExtension on Radius
ScrollFeatureExt on T
SeparatorBuilderExt on T
ShadowBuilderExt on T
SizeBuilderExt on T
SizeExtension on num
SpacingBuilderExt on T
StackFeatureExt on T
StepMixinExt on T
间隔多少,比如隔5个item,显示一条广告
StringImageTailWind on String
SvgBuilderExt on T
SvgStringExt on String?
TextAlignBuilderExt on T
TextBaselineBuilderExt on T
TextBuilderStringExt on String?
TextColorBuilderExt on T
TextCommonFeatureExt on T
TextDirectionBuilderExt on T
TooltipBuilderExt on T
WrapMixinExt on T

Constants

gapEmpty → const SizedBox
h10 → const HBox
h100 → const HBox
h12 → const HBox
h14 → const HBox
h16 → const HBox
h18 → const HBox
h2 → const HBox
h20 → const HBox
h22 → const HBox
h24 → const HBox
h26 → const HBox
h28 → const HBox
h30 → const HBox
h32 → const HBox
h34 → const HBox
h36 → const HBox
h38 → const HBox
h4 → const HBox
h40 → const HBox
h42 → const HBox
h44 → const HBox
h46 → const HBox
h48 → const HBox
h50 → const HBox
h52 → const HBox
h54 → const HBox
h56 → const HBox
h58 → const HBox
h6 → const HBox
h60 → const HBox
h62 → const HBox
h64 → const HBox
h66 → const HBox
h68 → const HBox
h70 → const HBox
h72 → const HBox
h74 → const HBox
h76 → const HBox
h78 → const HBox
h8 → const HBox
h80 → const HBox
h82 → const HBox
h84 → const HBox
h86 → const HBox
h88 → const HBox
h90 → const HBox
h92 → const HBox
h94 → const HBox
h96 → const HBox
h98 → const HBox
spacer → const Spacer
spacer2 → const Spacer
spacer3 → const Spacer
spacer4 → const Spacer
spacer5 → const Spacer
spacer6 → const Spacer
spacer7 → const Spacer
spacer8 → const Spacer
spacer9 → const Spacer
w10 → const WBox
w100 → const WBox
w12 → const WBox
w14 → const WBox
w16 → const WBox
w18 → const WBox
w2 → const WBox
w20 → const WBox
w22 → const WBox
w24 → const WBox
w26 → const WBox
w28 → const WBox
w30 → const WBox
w32 → const WBox
w34 → const WBox
w36 → const WBox
w38 → const WBox
w4 → const WBox
w40 → const WBox
w42 → const WBox
w44 → const WBox
w46 → const WBox
w48 → const WBox
w50 → const WBox
w52 → const WBox
w54 → const WBox
w56 → const WBox
w58 → const WBox
w6 → const WBox
w60 → const WBox
w62 → const WBox
w64 → const WBox
w66 → const WBox
w68 → const WBox
w70 → const WBox
w72 → const WBox
w74 → const WBox
w76 → const WBox
w78 → const WBox
w8 → const WBox
w80 → const WBox
w82 → const WBox
w84 → const WBox
w86 → const WBox
w88 → const WBox
w90 → const WBox
w92 → const WBox
w94 → const WBox
w96 → const WBox
w98 → const WBox

Properties

bd → _BoxDecorationBuilder
no setter
checkBox → _CheckBoxBuilder
Barry @date 2024/9/12 describe: eg: checkBox.blue.borderBlack.shadowMd.material.s50.onChanged(false, _onChanged)
no setter
column → _ColumnBuilder
Column
no setter
container ContainerBuilder
Don't have child,use mk to create empty container
no setter
gridview → _GridViewBuilder
GridView.builder
no setter
iconButton → _IconButtonBuilder
OutlinedButton.icon
no setter
linearGradient → _LinearGradientBuilder
no setter
listview → _ListViewBuilder
Barry @date 2024/8/24 describe: ListView.separated
no setter
p → _PBuilder
Barry @date 2024/8/26 describe:
no setter
p16 EdgeInsetsGeometry
getter/setter pair
p20 EdgeInsetsGeometry
getter/setter pair
padding → _Padding
Barry @date 2024/9/21 describe:
no setter
positioned → _PositionedBuilder
Barry @date 2024/12/2 describe:
no setter
radio → _RadioBuilder
Barry @date 2024/9/12 describe:
no setter
row → _RowBuilder
Row
no setter
shaderMask → _ShaderMaskBuilder
Barry @date 2024/9/17 describe:
no setter
sizedBox → _SizedBoxBuilder
Barry @date 2024/9/5 describe: SizedBox
no setter
stack → _StackBuilder
Stack
no setter
textRich RichTextBuilder
Text.rich
no setter
timeDilation double
Slows down animations by this factor to help in development.
no setter
ts TextStyleBuilder
no setter
wrap → _WrapBuilder
no setter

Functions

asset(String? path) ImageBuilder
Image.asset
elevatedButton([String? text]) → _ElevatedButtonBuilder
ElevatedButton.icon
icon(IconData icon) → _IconBuilder
Barry @date 2024/8/19 describe:
image(String? path) ImageBuilder
ImageLoader.image
outlinedButton([String? text]) → _OutlinedButtonBuilder
OutlinedButton.icon
strokeText(String? value) StrokeTextBuilder
svg(String file) → _SvgBuilder
Barry @date 2024/8/19 describe:
text(String? value) TextBuilder
Text
textButton([String? text]) → _TextButtonBuilder
TextButton.icon

Typedefs

FontSizeResolver = double Function(num fontSize, ScreenUtil instance)
ImageWidgetBuilder = Widget Function(BuildContext context, ImageProvider<Object> imageProvider)
Builder function to create an image widget. The function is called after the ImageProvider completes the image loading.
ItemListFunction<T> = Widget Function(BuildContext context, int index, T item)
LoadingErrorWidgetBuilder = Widget Function(BuildContext context, String url, Object error)
Builder function to create an error widget. This builder is called when the image failed loading, for example due to a 404 NotFound exception.
PlaceholderWidgetBuilder = Widget Function(BuildContext context, String url)
Builder function to create a placeholder widget. The function is called once while the ImageProvider is loading the image.
ProgressIndicatorBuilder = Widget Function(BuildContext context, String url, DownloadProgress progress)
Builder function to create a progress indicator widget. The function is called every time a chuck of the image is downloaded from the web, but at least once during image loading.
RebuildFactor = bool Function(MediaQueryData old, MediaQueryData data)
ScreenUtilInitBuilder = Widget Function(BuildContext context, Widget? child)