AlignmentBuilder mixin

Barry @date 2024/8/20 describe:

Mixin applications
Available extensions

Properties

alignment Alignment?
getter/setter pair
alignments List<Alignment>?
getter/setter pair
bottomCenter → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.bottomCenter
no setter
bottomLeft → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.bottomLeft
no setter
bottomRight → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.bottomRight
no setter
center → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.center
no setter
centerLeft → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.centerLeft
no setter
centerRight → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.centerRight
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topCenter → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.topCenter
no setter
topLeft → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.topLeft
no setter
topRight → T

Available on T, provided by the AlignmentBuilderExt extension

Alignment.topRight
no setter

Methods

align(Alignment? alignment) → T

Available on T, provided by the AlignmentBuilderExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited