ChildMkBuilder<T> class
abstract
- Inheritance
- Implementers
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mk → T
-
mk==make==build
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
child(
Widget child) → T -
click(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on T, provided by the MkBuilderExt extension
-
iconClick(
{GestureTapCallback? onTap}) → Widget -
Available on T, provided by the MkBuilderExt extension
-
inkWellClick(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on T, provided by the MkBuilderExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited