FontWeightBuilder mixin

Mixin applications
Available extensions

Properties

bold → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.bold
no setter
extrabold → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w800
no setter
extralight → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w200
no setter
fontBlack → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w900
no setter
hashCode int
The hash code for this object.
no setterinherited
innerFontWeight FontWeight?
getter/setter pair
light → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w300
no setter
medium → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w500
no setter
normal → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.normal
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semibold → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w600
no setter
thin → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w100
no setter
w100 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w100
no setter
w200 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w200
no setter
w300 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w300
no setter
w400 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w400
no setter
w500 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w500
no setter
w600 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w600
no setter
w700 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w700
no setter
w800 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w800
no setter
w900 → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.w900
no setter

Methods

fontWeight(FontWeight? weight) → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight weight
isBold(bool isBold) → T

Available on T, provided by the FontWeightBuilderExt extension

FontWeight.bold
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited