GridViewFeature mixin

Available extensions

Properties

childWidth10 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth100 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth110 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth120 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth130 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth140 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth150 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth160 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth170 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth180 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth190 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth20 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth200 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth210 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth220 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth230 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth240 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth250 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth260 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth270 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth280 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth290 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth30 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth300 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth40 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth50 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth60 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth70 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth80 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
childWidth90 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount10 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount2 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount3 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount4 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount5 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount6 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount7 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount8 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
crossAxisCount9 → T

Available on T, provided by the GridViewFeatureExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staggered → T

Available on T, provided by the GridViewFeatureExt extension

no setter

Methods

childWidth(double childWidth) → T

Available on T, provided by the GridViewFeatureExt extension

croAxisCount(int count) → T

Available on T, provided by the GridViewFeatureExt extension

maxCrossAxisExtent(double childWidth) → T

Available on T, provided by the GridViewFeatureExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited