LinearFeature mixin

Available extensions

Properties

center → T

Available on T, provided by the LinearFeatureExt extension

no setter
crossBaseline → T

Available on T, provided by the LinearFeatureExt extension

no setter
crossCenter → T

Available on T, provided by the LinearFeatureExt extension

no setter
crossEnd → T

Available on T, provided by the LinearFeatureExt extension

no setter
crossStart → T

Available on T, provided by the LinearFeatureExt extension

Cross 设置的状态
no setter
crossStretch → T

Available on T, provided by the LinearFeatureExt extension

no setter
end → T

Available on T, provided by the LinearFeatureExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
max → T

Available on T, provided by the LinearFeatureExt extension

no setter
min → T

Available on T, provided by the LinearFeatureExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceAround → T

Available on T, provided by the LinearFeatureExt extension

no setter
spaceBetween → T

Available on T, provided by the LinearFeatureExt extension

no setter
spaceEvenly → T

Available on T, provided by the LinearFeatureExt extension

no setter
start → T

Available on T, provided by the LinearFeatureExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited