ShadowBuilder mixin

Barry @date 2024/8/24 describe:

Mixin applications
Available extensions

Properties

adaptedBoxShadow List<BoxShadow>?
阴影不做 ScreenUtil(sr) 缩放,直接使用固定 px —— 与 web Tailwind 像素级一致。
no setter
boxShadow List<BoxShadow>?
getter/setter pair
cardShadow → T

Available on T, provided by the ShadowBuilderExt extension

柔和卡片阴影(介于 shadow / shadow-md 之间的轻阴影)
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow2xl → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow-2xl: 0 25px 50px -12px rgb(0 0 0 / 0.25)
no setter
shadowBase → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow (DEFAULT): 0 1px 3px 0/.1, 0 1px 2px -1px/.1
no setter
shadowLg → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow-lg: 0 10px 15px -3px/.1, 0 4px 6px -4px/.1
no setter
shadowMd → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow-md: 0 4px 6px -1px/.1, 0 2px 4px -2px/.1
no setter
shadowSm → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow-sm: 0 1px 2px 0 rgb(0 0 0 / 0.05)
no setter
shadowXl → T

Available on T, provided by the ShadowBuilderExt extension

Tailwind shadow-xl: 0 20px 25px -5px/.1, 0 8px 10px -6px/.1
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shadow(List<BoxShadow> boxShadow) → T

Available on T, provided by the ShadowBuilderExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited