SizeBuilder mixin

Barry @date 2024/8/20 describe:

Mixin applications
Available extensions

Properties

h1 → T

Available on T, provided by the SizeBuilderExt extension

set the height 1
no setter
h10 → T

Available on T, provided by the SizeBuilderExt extension

set the height 10
no setter
h100 → T

Available on T, provided by the SizeBuilderExt extension

set the height 100
no setter
h105 → T

Available on T, provided by the SizeBuilderExt extension

set the height 105
no setter
h11 → T

Available on T, provided by the SizeBuilderExt extension

set the height 11
no setter
h110 → T

Available on T, provided by the SizeBuilderExt extension

set the height 110
no setter
h115 → T

Available on T, provided by the SizeBuilderExt extension

set the height 115
no setter
h12 → T

Available on T, provided by the SizeBuilderExt extension

set the height 12
no setter
h120 → T

Available on T, provided by the SizeBuilderExt extension

set the height 120
no setter
h125 → T

Available on T, provided by the SizeBuilderExt extension

set the height 125
no setter
h13 → T

Available on T, provided by the SizeBuilderExt extension

set the height 13
no setter
h130 → T

Available on T, provided by the SizeBuilderExt extension

set the height 130
no setter
h135 → T

Available on T, provided by the SizeBuilderExt extension

set the height 135
no setter
h14 → T

Available on T, provided by the SizeBuilderExt extension

set the height 14
no setter
h140 → T

Available on T, provided by the SizeBuilderExt extension

set the height 140
no setter
h145 → T

Available on T, provided by the SizeBuilderExt extension

set the height 145
no setter
h15 → T

Available on T, provided by the SizeBuilderExt extension

set the height 15
no setter
h150 → T

Available on T, provided by the SizeBuilderExt extension

set the height 150
no setter
h155 → T

Available on T, provided by the SizeBuilderExt extension

set the height 155
no setter
h16 → T

Available on T, provided by the SizeBuilderExt extension

set the height 16
no setter
h160 → T

Available on T, provided by the SizeBuilderExt extension

set the height 160
no setter
h165 → T

Available on T, provided by the SizeBuilderExt extension

set the height 165
no setter
h17 → T

Available on T, provided by the SizeBuilderExt extension

set the height 17
no setter
h170 → T

Available on T, provided by the SizeBuilderExt extension

set the height 170
no setter
h175 → T

Available on T, provided by the SizeBuilderExt extension

set the height 175
no setter
h18 → T

Available on T, provided by the SizeBuilderExt extension

set the height 18
no setter
h180 → T

Available on T, provided by the SizeBuilderExt extension

set the height 180
no setter
h185 → T

Available on T, provided by the SizeBuilderExt extension

set the height 185
no setter
h19 → T

Available on T, provided by the SizeBuilderExt extension

set the height 19
no setter
h190 → T

Available on T, provided by the SizeBuilderExt extension

set the height 190
no setter
h195 → T

Available on T, provided by the SizeBuilderExt extension

set the height 195
no setter
h2 → T

Available on T, provided by the SizeBuilderExt extension

set the height 2
no setter
h20 → T

Available on T, provided by the SizeBuilderExt extension

set the height 20
no setter
h200 → T

Available on T, provided by the SizeBuilderExt extension

set the height 200
no setter
h205 → T

Available on T, provided by the SizeBuilderExt extension

set the height 205
no setter
h210 → T

Available on T, provided by the SizeBuilderExt extension

set the height 210
no setter
h215 → T

Available on T, provided by the SizeBuilderExt extension

set the height 215
no setter
h22 → T

Available on T, provided by the SizeBuilderExt extension

set the height 22
no setter
h220 → T

Available on T, provided by the SizeBuilderExt extension

set the height 220
no setter
h225 → T

Available on T, provided by the SizeBuilderExt extension

set the height 225
no setter
h230 → T

Available on T, provided by the SizeBuilderExt extension

set the height 230
no setter
h235 → T

Available on T, provided by the SizeBuilderExt extension

set the height 235
no setter
h24 → T

Available on T, provided by the SizeBuilderExt extension

set the height 24
no setter
h240 → T

Available on T, provided by the SizeBuilderExt extension

set the height 240
no setter
h245 → T

Available on T, provided by the SizeBuilderExt extension

set the height 245
no setter
h250 → T

Available on T, provided by the SizeBuilderExt extension

set the height 250
no setter
h255 → T

Available on T, provided by the SizeBuilderExt extension

set the height 255
no setter
h26 → T

Available on T, provided by the SizeBuilderExt extension

set the height 26
no setter
h260 → T

Available on T, provided by the SizeBuilderExt extension

set the height 260
no setter
h265 → T

Available on T, provided by the SizeBuilderExt extension

set the height 265
no setter
h270 → T

Available on T, provided by the SizeBuilderExt extension

set the height 270
no setter
h275 → T

Available on T, provided by the SizeBuilderExt extension

set the height 275
no setter
h28 → T

Available on T, provided by the SizeBuilderExt extension

set the height 28
no setter
h280 → T

Available on T, provided by the SizeBuilderExt extension

set the height 280
no setter
h285 → T

Available on T, provided by the SizeBuilderExt extension

set the height 285
no setter
h290 → T

Available on T, provided by the SizeBuilderExt extension

set the height 290
no setter
h295 → T

Available on T, provided by the SizeBuilderExt extension

set the height 295
no setter
h3 → T

Available on T, provided by the SizeBuilderExt extension

set the height 3
no setter
h30 → T

Available on T, provided by the SizeBuilderExt extension

set the height 30
no setter
h300 → T

Available on T, provided by the SizeBuilderExt extension

set the height 300
no setter
h305 → T

Available on T, provided by the SizeBuilderExt extension

set the height 305
no setter
h310 → T

Available on T, provided by the SizeBuilderExt extension

set the height 310
no setter
h315 → T

Available on T, provided by the SizeBuilderExt extension

set the height 315
no setter
h32 → T

Available on T, provided by the SizeBuilderExt extension

set the height 32
no setter
h320 → T

Available on T, provided by the SizeBuilderExt extension

set the height 320
no setter
h325 → T

Available on T, provided by the SizeBuilderExt extension

set the height 325
no setter
h330 → T

Available on T, provided by the SizeBuilderExt extension

set the height 330
no setter
h335 → T

Available on T, provided by the SizeBuilderExt extension

set the height 335
no setter
h34 → T

Available on T, provided by the SizeBuilderExt extension

set the height 34
no setter
h340 → T

Available on T, provided by the SizeBuilderExt extension

set the height 340
no setter
h345 → T

Available on T, provided by the SizeBuilderExt extension

set the height 345
no setter
h350 → T

Available on T, provided by the SizeBuilderExt extension

set the height 350
no setter
h355 → T

Available on T, provided by the SizeBuilderExt extension

set the height 355
no setter
h36 → T

Available on T, provided by the SizeBuilderExt extension

set the height 36
no setter
h360 → T

Available on T, provided by the SizeBuilderExt extension

set the height 360
no setter
h365 → T

Available on T, provided by the SizeBuilderExt extension

set the height 365
no setter
h370 → T

Available on T, provided by the SizeBuilderExt extension

set the height 370
no setter
h375 → T

Available on T, provided by the SizeBuilderExt extension

set the height 375
no setter
h38 → T

Available on T, provided by the SizeBuilderExt extension

set the height 38
no setter
h380 → T

Available on T, provided by the SizeBuilderExt extension

set the height 380
no setter
h385 → T

Available on T, provided by the SizeBuilderExt extension

set the height 385
no setter
h390 → T

Available on T, provided by the SizeBuilderExt extension

set the height 390
no setter
h395 → T

Available on T, provided by the SizeBuilderExt extension

set the height 395
no setter
h4 → T

Available on T, provided by the SizeBuilderExt extension

set the height 4
no setter
h40 → T

Available on T, provided by the SizeBuilderExt extension

set the height 40
no setter
h400 → T

Available on T, provided by the SizeBuilderExt extension

set the height 400
no setter
h42 → T

Available on T, provided by the SizeBuilderExt extension

set the height 42
no setter
h44 → T

Available on T, provided by the SizeBuilderExt extension

set the height 44
no setter
h46 → T

Available on T, provided by the SizeBuilderExt extension

set the height 46
no setter
h48 → T

Available on T, provided by the SizeBuilderExt extension

set the height 48
no setter
h5 → T

Available on T, provided by the SizeBuilderExt extension

set the height 5
no setter
h50 → T

Available on T, provided by the SizeBuilderExt extension

set the height 50
no setter
h52 → T

Available on T, provided by the SizeBuilderExt extension

set the height 52
no setter
h54 → T

Available on T, provided by the SizeBuilderExt extension

set the height 54
no setter
h55 → T

Available on T, provided by the SizeBuilderExt extension

set the height 55
no setter
h56 → T

Available on T, provided by the SizeBuilderExt extension

set the height 56
no setter
h58 → T

Available on T, provided by the SizeBuilderExt extension

set the height 58
no setter
h6 → T

Available on T, provided by the SizeBuilderExt extension

set the height 6
no setter
h60 → T

Available on T, provided by the SizeBuilderExt extension

set the height 60
no setter
h62 → T

Available on T, provided by the SizeBuilderExt extension

set the height 62
no setter
h64 → T

Available on T, provided by the SizeBuilderExt extension

set the height 64
no setter
h65 → T

Available on T, provided by the SizeBuilderExt extension

set the height 65
no setter
h66 → T

Available on T, provided by the SizeBuilderExt extension

set the height 66
no setter
h68 → T

Available on T, provided by the SizeBuilderExt extension

set the height 68
no setter
h7 → T

Available on T, provided by the SizeBuilderExt extension

set the height 7
no setter
h70 → T

Available on T, provided by the SizeBuilderExt extension

set the height 70
no setter
h72 → T

Available on T, provided by the SizeBuilderExt extension

set the height 72
no setter
h74 → T

Available on T, provided by the SizeBuilderExt extension

set the height 74
no setter
h75 → T

Available on T, provided by the SizeBuilderExt extension

set the height 75
no setter
h76 → T

Available on T, provided by the SizeBuilderExt extension

set the height 76
no setter
h78 → T

Available on T, provided by the SizeBuilderExt extension

set the height 78
no setter
h8 → T

Available on T, provided by the SizeBuilderExt extension

set the height 8
no setter
h80 → T

Available on T, provided by the SizeBuilderExt extension

set the height 80
no setter
h82 → T

Available on T, provided by the SizeBuilderExt extension

set the height 82
no setter
h84 → T

Available on T, provided by the SizeBuilderExt extension

set the height 84
no setter
h85 → T

Available on T, provided by the SizeBuilderExt extension

set the height 85
no setter
h86 → T

Available on T, provided by the SizeBuilderExt extension

set the height 86
no setter
h88 → T

Available on T, provided by the SizeBuilderExt extension

set the height 88
no setter
h9 → T

Available on T, provided by the SizeBuilderExt extension

set the height 9
no setter
h90 → T

Available on T, provided by the SizeBuilderExt extension

set the height 90
no setter
h92 → T

Available on T, provided by the SizeBuilderExt extension

set the height 92
no setter
h94 → T

Available on T, provided by the SizeBuilderExt extension

set the height 94
no setter
h95 → T

Available on T, provided by the SizeBuilderExt extension

set the height 95
no setter
h96 → T

Available on T, provided by the SizeBuilderExt extension

set the height 96
no setter
h98 → T

Available on T, provided by the SizeBuilderExt extension

set the height 98
no setter
hasConstraint bool
no setter
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
hFull → T

Available on T, provided by the SizeBuilderExt extension

set the height _scree
no setter
hFull10 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 10
no setter
hFull15 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 15
no setter
hFull20 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 20
no setter
hFull25 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 25
no setter
hFull30 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 30
no setter
hFull35 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 35
no setter
hFull40 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 40
no setter
hFull45 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 45
no setter
hFull5 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 5
no setter
hFull50 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 50
no setter
hFull55 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 55
no setter
hFull60 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 60
no setter
hFull65 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 65
no setter
hFull70 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 70
no setter
hFull75 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 75
no setter
hFull80 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 80
no setter
hFull85 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 85
no setter
hFull90 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 90
no setter
hFull95 → T

Available on T, provided by the SizeBuilderExt extension

set the height _screenH 95
no setter
hInfinity → T

Available on T, provided by the SizeBuilderExt extension

set the height double.infini
no setter
innerMaxHeight double?
getter/setter pair
innerMaxWidth double?
getter/setter pair
innerMinHeight double?
getter/setter pair
innerMinWidth double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s1 → T

Available on T, provided by the SizeBuilderExt extension

set the size 1
no setter
s10 → T

Available on T, provided by the SizeBuilderExt extension

set the size 10
no setter
s100 → T

Available on T, provided by the SizeBuilderExt extension

set the size 100
no setter
s105 → T

Available on T, provided by the SizeBuilderExt extension

set the size 105
no setter
s11 → T

Available on T, provided by the SizeBuilderExt extension

set the size 11
no setter
s110 → T

Available on T, provided by the SizeBuilderExt extension

set the size 110
no setter
s115 → T

Available on T, provided by the SizeBuilderExt extension

set the size 115
no setter
s12 → T

Available on T, provided by the SizeBuilderExt extension

set the size 12
no setter
s120 → T

Available on T, provided by the SizeBuilderExt extension

set the size 120
no setter
s125 → T

Available on T, provided by the SizeBuilderExt extension

set the size 125
no setter
s13 → T

Available on T, provided by the SizeBuilderExt extension

set the size 13
no setter
s130 → T

Available on T, provided by the SizeBuilderExt extension

set the size 130
no setter
s135 → T

Available on T, provided by the SizeBuilderExt extension

set the size 135
no setter
s14 → T

Available on T, provided by the SizeBuilderExt extension

set the size 14
no setter
s140 → T

Available on T, provided by the SizeBuilderExt extension

set the size 140
no setter
s145 → T

Available on T, provided by the SizeBuilderExt extension

set the size 145
no setter
s15 → T

Available on T, provided by the SizeBuilderExt extension

set the size 15
no setter
s150 → T

Available on T, provided by the SizeBuilderExt extension

set the size 150
no setter
s155 → T

Available on T, provided by the SizeBuilderExt extension

set the size 155
no setter
s16 → T

Available on T, provided by the SizeBuilderExt extension

set the size 16
no setter
s160 → T

Available on T, provided by the SizeBuilderExt extension

set the size 160
no setter
s165 → T

Available on T, provided by the SizeBuilderExt extension

set the size 165
no setter
s17 → T

Available on T, provided by the SizeBuilderExt extension

set the size 17
no setter
s170 → T

Available on T, provided by the SizeBuilderExt extension

set the size 170
no setter
s175 → T

Available on T, provided by the SizeBuilderExt extension

set the size 175
no setter
s18 → T

Available on T, provided by the SizeBuilderExt extension

set the size 18
no setter
s180 → T

Available on T, provided by the SizeBuilderExt extension

set the size 180
no setter
s185 → T

Available on T, provided by the SizeBuilderExt extension

set the size 185
no setter
s19 → T

Available on T, provided by the SizeBuilderExt extension

set the size 19
no setter
s190 → T

Available on T, provided by the SizeBuilderExt extension

set the size 190
no setter
s195 → T

Available on T, provided by the SizeBuilderExt extension

set the size 195
no setter
s2 → T

Available on T, provided by the SizeBuilderExt extension

set the size 2
no setter
s20 → T

Available on T, provided by the SizeBuilderExt extension

set the size 20
no setter
s200 → T

Available on T, provided by the SizeBuilderExt extension

set the size 200
no setter
s205 → T

Available on T, provided by the SizeBuilderExt extension

set the size 205
no setter
s210 → T

Available on T, provided by the SizeBuilderExt extension

set the size 210
no setter
s215 → T

Available on T, provided by the SizeBuilderExt extension

set the size 215
no setter
s22 → T

Available on T, provided by the SizeBuilderExt extension

set the size 22
no setter
s220 → T

Available on T, provided by the SizeBuilderExt extension

set the size 220
no setter
s225 → T

Available on T, provided by the SizeBuilderExt extension

set the size 225
no setter
s230 → T

Available on T, provided by the SizeBuilderExt extension

set the size 230
no setter
s235 → T

Available on T, provided by the SizeBuilderExt extension

set the size 235
no setter
s24 → T

Available on T, provided by the SizeBuilderExt extension

set the size 24
no setter
s240 → T

Available on T, provided by the SizeBuilderExt extension

set the size 240
no setter
s245 → T

Available on T, provided by the SizeBuilderExt extension

set the size 245
no setter
s250 → T

Available on T, provided by the SizeBuilderExt extension

set the size 250
no setter
s255 → T

Available on T, provided by the SizeBuilderExt extension

set the size 255
no setter
s26 → T

Available on T, provided by the SizeBuilderExt extension

set the size 26
no setter
s260 → T

Available on T, provided by the SizeBuilderExt extension

set the size 260
no setter
s265 → T

Available on T, provided by the SizeBuilderExt extension

set the size 265
no setter
s270 → T

Available on T, provided by the SizeBuilderExt extension

set the size 270
no setter
s275 → T

Available on T, provided by the SizeBuilderExt extension

set the size 275
no setter
s28 → T

Available on T, provided by the SizeBuilderExt extension

set the size 28
no setter
s280 → T

Available on T, provided by the SizeBuilderExt extension

set the size 280
no setter
s285 → T

Available on T, provided by the SizeBuilderExt extension

set the size 285
no setter
s290 → T

Available on T, provided by the SizeBuilderExt extension

set the size 290
no setter
s295 → T

Available on T, provided by the SizeBuilderExt extension

set the size 295
no setter
s3 → T

Available on T, provided by the SizeBuilderExt extension

set the size 3
no setter
s30 → T

Available on T, provided by the SizeBuilderExt extension

set the size 30
no setter
s300 → T

Available on T, provided by the SizeBuilderExt extension

set the size 300
no setter
s305 → T

Available on T, provided by the SizeBuilderExt extension

set the size 305
no setter
s310 → T

Available on T, provided by the SizeBuilderExt extension

set the size 310
no setter
s315 → T

Available on T, provided by the SizeBuilderExt extension

set the size 315
no setter
s32 → T

Available on T, provided by the SizeBuilderExt extension

set the size 32
no setter
s320 → T

Available on T, provided by the SizeBuilderExt extension

set the size 320
no setter
s325 → T

Available on T, provided by the SizeBuilderExt extension

set the size 325
no setter
s330 → T

Available on T, provided by the SizeBuilderExt extension

set the size 330
no setter
s335 → T

Available on T, provided by the SizeBuilderExt extension

set the size 335
no setter
s34 → T

Available on T, provided by the SizeBuilderExt extension

set the size 34
no setter
s340 → T

Available on T, provided by the SizeBuilderExt extension

set the size 340
no setter
s345 → T

Available on T, provided by the SizeBuilderExt extension

set the size 345
no setter
s350 → T

Available on T, provided by the SizeBuilderExt extension

set the size 350
no setter
s355 → T

Available on T, provided by the SizeBuilderExt extension

set the size 355
no setter
s36 → T

Available on T, provided by the SizeBuilderExt extension

set the size 36
no setter
s360 → T

Available on T, provided by the SizeBuilderExt extension

set the size 360
no setter
s365 → T

Available on T, provided by the SizeBuilderExt extension

set the size 365
no setter
s370 → T

Available on T, provided by the SizeBuilderExt extension

set the size 370
no setter
s375 → T

Available on T, provided by the SizeBuilderExt extension

set the size 375
no setter
s38 → T

Available on T, provided by the SizeBuilderExt extension

set the size 38
no setter
s380 → T

Available on T, provided by the SizeBuilderExt extension

set the size 380
no setter
s385 → T

Available on T, provided by the SizeBuilderExt extension

set the size 385
no setter
s390 → T

Available on T, provided by the SizeBuilderExt extension

set the size 390
no setter
s395 → T

Available on T, provided by the SizeBuilderExt extension

set the size 395
no setter
s4 → T

Available on T, provided by the SizeBuilderExt extension

set the size 4
no setter
s40 → T

Available on T, provided by the SizeBuilderExt extension

set the size 40
no setter
s400 → T

Available on T, provided by the SizeBuilderExt extension

set the size 400
no setter
s42 → T

Available on T, provided by the SizeBuilderExt extension

set the size 42
no setter
s44 → T

Available on T, provided by the SizeBuilderExt extension

set the size 44
no setter
s46 → T

Available on T, provided by the SizeBuilderExt extension

set the size 46
no setter
s48 → T

Available on T, provided by the SizeBuilderExt extension

set the size 48
no setter
s5 → T

Available on T, provided by the SizeBuilderExt extension

set the size 5
no setter
s50 → T

Available on T, provided by the SizeBuilderExt extension

set the size 50
no setter
s52 → T

Available on T, provided by the SizeBuilderExt extension

set the size 52
no setter
s54 → T

Available on T, provided by the SizeBuilderExt extension

set the size 54
no setter
s55 → T

Available on T, provided by the SizeBuilderExt extension

set the size 55
no setter
s56 → T

Available on T, provided by the SizeBuilderExt extension

set the size 56
no setter
s58 → T

Available on T, provided by the SizeBuilderExt extension

set the size 58
no setter
s6 → T

Available on T, provided by the SizeBuilderExt extension

set the size 6
no setter
s60 → T

Available on T, provided by the SizeBuilderExt extension

set the size 60
no setter
s62 → T

Available on T, provided by the SizeBuilderExt extension

set the size 62
no setter
s64 → T

Available on T, provided by the SizeBuilderExt extension

set the size 64
no setter
s65 → T

Available on T, provided by the SizeBuilderExt extension

set the size 65
no setter
s66 → T

Available on T, provided by the SizeBuilderExt extension

set the size 66
no setter
s68 → T

Available on T, provided by the SizeBuilderExt extension

set the size 68
no setter
s7 → T

Available on T, provided by the SizeBuilderExt extension

set the size 7
no setter
s70 → T

Available on T, provided by the SizeBuilderExt extension

set the size 70
no setter
s72 → T

Available on T, provided by the SizeBuilderExt extension

set the size 72
no setter
s74 → T

Available on T, provided by the SizeBuilderExt extension

set the size 74
no setter
s75 → T

Available on T, provided by the SizeBuilderExt extension

set the size 75
no setter
s76 → T

Available on T, provided by the SizeBuilderExt extension

set the size 76
no setter
s78 → T

Available on T, provided by the SizeBuilderExt extension

set the size 78
no setter
s8 → T

Available on T, provided by the SizeBuilderExt extension

set the size 8
no setter
s80 → T

Available on T, provided by the SizeBuilderExt extension

set the size 80
no setter
s82 → T

Available on T, provided by the SizeBuilderExt extension

set the size 82
no setter
s84 → T

Available on T, provided by the SizeBuilderExt extension

set the size 84
no setter
s85 → T

Available on T, provided by the SizeBuilderExt extension

set the size 85
no setter
s86 → T

Available on T, provided by the SizeBuilderExt extension

set the size 86
no setter
s88 → T

Available on T, provided by the SizeBuilderExt extension

set the size 88
no setter
s9 → T

Available on T, provided by the SizeBuilderExt extension

set the size 9
no setter
s90 → T

Available on T, provided by the SizeBuilderExt extension

set the size 90
no setter
s92 → T

Available on T, provided by the SizeBuilderExt extension

set the size 92
no setter
s94 → T

Available on T, provided by the SizeBuilderExt extension

set the size 94
no setter
s95 → T

Available on T, provided by the SizeBuilderExt extension

set the size 95
no setter
s96 → T

Available on T, provided by the SizeBuilderExt extension

set the size 96
no setter
s98 → T

Available on T, provided by the SizeBuilderExt extension

set the size 98
no setter
sFull → T

Available on T, provided by the SizeBuilderExt extension

no setter
sFull10 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *10
no setter
sFull15 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *15
no setter
sFull20 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *20
no setter
sFull25 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *25
no setter
sFull30 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *30
no setter
sFull35 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *35
no setter
sFull40 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *40
no setter
sFull45 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *45
no setter
sFull5 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *5
no setter
sFull50 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *50
no setter
sFull55 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *55
no setter
sFull60 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *60
no setter
sFull65 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *65
no setter
sFull70 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *70
no setter
sFull75 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *75
no setter
sFull80 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *80
no setter
sFull85 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *85
no setter
sFull90 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *90
no setter
sFull95 → T

Available on T, provided by the SizeBuilderExt extension

set the width and the width or height is its *95
no setter
sInfinity → T

Available on T, provided by the SizeBuilderExt extension

no setter
size double?
getter/setter pair
sScreenH → T

Available on T, provided by the SizeBuilderExt extension

no setter
sScreenW → T

Available on T, provided by the SizeBuilderExt extension

no setter
w1 → T

Available on T, provided by the SizeBuilderExt extension

set the width 1
no setter
w10 → T

Available on T, provided by the SizeBuilderExt extension

set the width 10
no setter
w100 → T

Available on T, provided by the SizeBuilderExt extension

set the width 100
no setter
w105 → T

Available on T, provided by the SizeBuilderExt extension

set the width 105
no setter
w11 → T

Available on T, provided by the SizeBuilderExt extension

set the width 11
no setter
w110 → T

Available on T, provided by the SizeBuilderExt extension

set the width 110
no setter
w115 → T

Available on T, provided by the SizeBuilderExt extension

set the width 115
no setter
w12 → T

Available on T, provided by the SizeBuilderExt extension

set the width 12
no setter
w120 → T

Available on T, provided by the SizeBuilderExt extension

set the width 120
no setter
w125 → T

Available on T, provided by the SizeBuilderExt extension

set the width 125
no setter
w13 → T

Available on T, provided by the SizeBuilderExt extension

set the width 13
no setter
w130 → T

Available on T, provided by the SizeBuilderExt extension

set the width 130
no setter
w135 → T

Available on T, provided by the SizeBuilderExt extension

set the width 135
no setter
w14 → T

Available on T, provided by the SizeBuilderExt extension

set the width 14
no setter
w140 → T

Available on T, provided by the SizeBuilderExt extension

set the width 140
no setter
w145 → T

Available on T, provided by the SizeBuilderExt extension

set the width 145
no setter
w15 → T

Available on T, provided by the SizeBuilderExt extension

set the width 15
no setter
w150 → T

Available on T, provided by the SizeBuilderExt extension

set the width 150
no setter
w155 → T

Available on T, provided by the SizeBuilderExt extension

set the width 155
no setter
w16 → T

Available on T, provided by the SizeBuilderExt extension

set the width 16
no setter
w160 → T

Available on T, provided by the SizeBuilderExt extension

set the width 160
no setter
w165 → T

Available on T, provided by the SizeBuilderExt extension

set the width 165
no setter
w17 → T

Available on T, provided by the SizeBuilderExt extension

set the width 17
no setter
w170 → T

Available on T, provided by the SizeBuilderExt extension

set the width 170
no setter
w175 → T

Available on T, provided by the SizeBuilderExt extension

set the width 175
no setter
w18 → T

Available on T, provided by the SizeBuilderExt extension

set the width 18
no setter
w180 → T

Available on T, provided by the SizeBuilderExt extension

set the width 180
no setter
w185 → T

Available on T, provided by the SizeBuilderExt extension

set the width 185
no setter
w19 → T

Available on T, provided by the SizeBuilderExt extension

set the width 19
no setter
w190 → T

Available on T, provided by the SizeBuilderExt extension

set the width 190
no setter
w195 → T

Available on T, provided by the SizeBuilderExt extension

set the width 195
no setter
w2 → T

Available on T, provided by the SizeBuilderExt extension

set the width 2
no setter
w20 → T

Available on T, provided by the SizeBuilderExt extension

set the width 20
no setter
w200 → T

Available on T, provided by the SizeBuilderExt extension

set the width 200
no setter
w205 → T

Available on T, provided by the SizeBuilderExt extension

set the width 205
no setter
w210 → T

Available on T, provided by the SizeBuilderExt extension

set the width 210
no setter
w215 → T

Available on T, provided by the SizeBuilderExt extension

set the width 215
no setter
w22 → T

Available on T, provided by the SizeBuilderExt extension

set the width 22
no setter
w220 → T

Available on T, provided by the SizeBuilderExt extension

set the width 220
no setter
w225 → T

Available on T, provided by the SizeBuilderExt extension

set the width 225
no setter
w230 → T

Available on T, provided by the SizeBuilderExt extension

set the width 230
no setter
w235 → T

Available on T, provided by the SizeBuilderExt extension

set the width 235
no setter
w24 → T

Available on T, provided by the SizeBuilderExt extension

set the width 24
no setter
w240 → T

Available on T, provided by the SizeBuilderExt extension

set the width 240
no setter
w245 → T

Available on T, provided by the SizeBuilderExt extension

set the width 245
no setter
w250 → T

Available on T, provided by the SizeBuilderExt extension

set the width 250
no setter
w255 → T

Available on T, provided by the SizeBuilderExt extension

set the width 255
no setter
w26 → T

Available on T, provided by the SizeBuilderExt extension

set the width 26
no setter
w260 → T

Available on T, provided by the SizeBuilderExt extension

set the width 260
no setter
w265 → T

Available on T, provided by the SizeBuilderExt extension

set the width 265
no setter
w270 → T

Available on T, provided by the SizeBuilderExt extension

set the width 270
no setter
w275 → T

Available on T, provided by the SizeBuilderExt extension

set the width 275
no setter
w28 → T

Available on T, provided by the SizeBuilderExt extension

set the width 28
no setter
w280 → T

Available on T, provided by the SizeBuilderExt extension

set the width 280
no setter
w285 → T

Available on T, provided by the SizeBuilderExt extension

set the width 285
no setter
w290 → T

Available on T, provided by the SizeBuilderExt extension

set the width 290
no setter
w295 → T

Available on T, provided by the SizeBuilderExt extension

set the width 295
no setter
w3 → T

Available on T, provided by the SizeBuilderExt extension

set the width 3
no setter
w30 → T

Available on T, provided by the SizeBuilderExt extension

set the width 30
no setter
w300 → T

Available on T, provided by the SizeBuilderExt extension

set the width 300
no setter
w305 → T

Available on T, provided by the SizeBuilderExt extension

set the width 305
no setter
w310 → T

Available on T, provided by the SizeBuilderExt extension

set the width 310
no setter
w315 → T

Available on T, provided by the SizeBuilderExt extension

set the width 315
no setter
w32 → T

Available on T, provided by the SizeBuilderExt extension

set the width 32
no setter
w320 → T

Available on T, provided by the SizeBuilderExt extension

set the width 320
no setter
w325 → T

Available on T, provided by the SizeBuilderExt extension

set the width 325
no setter
w330 → T

Available on T, provided by the SizeBuilderExt extension

set the width 330
no setter
w335 → T

Available on T, provided by the SizeBuilderExt extension

set the width 335
no setter
w34 → T

Available on T, provided by the SizeBuilderExt extension

set the width 34
no setter
w340 → T

Available on T, provided by the SizeBuilderExt extension

set the width 340
no setter
w345 → T

Available on T, provided by the SizeBuilderExt extension

set the width 345
no setter
w350 → T

Available on T, provided by the SizeBuilderExt extension

set the width 350
no setter
w355 → T

Available on T, provided by the SizeBuilderExt extension

set the width 355
no setter
w36 → T

Available on T, provided by the SizeBuilderExt extension

set the width 36
no setter
w360 → T

Available on T, provided by the SizeBuilderExt extension

set the width 360
no setter
w365 → T

Available on T, provided by the SizeBuilderExt extension

set the width 365
no setter
w370 → T

Available on T, provided by the SizeBuilderExt extension

set the width 370
no setter
w375 → T

Available on T, provided by the SizeBuilderExt extension

set the width 375
no setter
w38 → T

Available on T, provided by the SizeBuilderExt extension

set the width 38
no setter
w380 → T

Available on T, provided by the SizeBuilderExt extension

set the width 380
no setter
w385 → T

Available on T, provided by the SizeBuilderExt extension

set the width 385
no setter
w390 → T

Available on T, provided by the SizeBuilderExt extension

set the width 390
no setter
w395 → T

Available on T, provided by the SizeBuilderExt extension

set the width 395
no setter
w4 → T

Available on T, provided by the SizeBuilderExt extension

set the width 4
no setter
w40 → T

Available on T, provided by the SizeBuilderExt extension

set the width 40
no setter
w400 → T

Available on T, provided by the SizeBuilderExt extension

set the width 400
no setter
w42 → T

Available on T, provided by the SizeBuilderExt extension

set the width 42
no setter
w44 → T

Available on T, provided by the SizeBuilderExt extension

set the width 44
no setter
w46 → T

Available on T, provided by the SizeBuilderExt extension

set the width 46
no setter
w48 → T

Available on T, provided by the SizeBuilderExt extension

set the width 48
no setter
w5 → T

Available on T, provided by the SizeBuilderExt extension

set the width 5
no setter
w50 → T

Available on T, provided by the SizeBuilderExt extension

set the width 50
no setter
w52 → T

Available on T, provided by the SizeBuilderExt extension

set the width 52
no setter
w54 → T

Available on T, provided by the SizeBuilderExt extension

set the width 54
no setter
w55 → T

Available on T, provided by the SizeBuilderExt extension

set the width 55
no setter
w56 → T

Available on T, provided by the SizeBuilderExt extension

set the width 56
no setter
w58 → T

Available on T, provided by the SizeBuilderExt extension

set the width 58
no setter
w6 → T

Available on T, provided by the SizeBuilderExt extension

set the width 6
no setter
w60 → T

Available on T, provided by the SizeBuilderExt extension

set the width 60
no setter
w62 → T

Available on T, provided by the SizeBuilderExt extension

set the width 62
no setter
w64 → T

Available on T, provided by the SizeBuilderExt extension

set the width 64
no setter
w65 → T

Available on T, provided by the SizeBuilderExt extension

set the width 65
no setter
w66 → T

Available on T, provided by the SizeBuilderExt extension

set the width 66
no setter
w68 → T

Available on T, provided by the SizeBuilderExt extension

set the width 68
no setter
w7 → T

Available on T, provided by the SizeBuilderExt extension

set the width 7
no setter
w70 → T

Available on T, provided by the SizeBuilderExt extension

set the width 70
no setter
w72 → T

Available on T, provided by the SizeBuilderExt extension

set the width 72
no setter
w74 → T

Available on T, provided by the SizeBuilderExt extension

set the width 74
no setter
w75 → T

Available on T, provided by the SizeBuilderExt extension

set the width 75
no setter
w76 → T

Available on T, provided by the SizeBuilderExt extension

set the width 76
no setter
w78 → T

Available on T, provided by the SizeBuilderExt extension

set the width 78
no setter
w8 → T

Available on T, provided by the SizeBuilderExt extension

set the width 8
no setter
w80 → T

Available on T, provided by the SizeBuilderExt extension

set the width 80
no setter
w82 → T

Available on T, provided by the SizeBuilderExt extension

set the width 82
no setter
w84 → T

Available on T, provided by the SizeBuilderExt extension

set the width 84
no setter
w85 → T

Available on T, provided by the SizeBuilderExt extension

set the width 85
no setter
w86 → T

Available on T, provided by the SizeBuilderExt extension

set the width 86
no setter
w88 → T

Available on T, provided by the SizeBuilderExt extension

set the width 88
no setter
w9 → T

Available on T, provided by the SizeBuilderExt extension

set the width 9
no setter
w90 → T

Available on T, provided by the SizeBuilderExt extension

set the width 90
no setter
w92 → T

Available on T, provided by the SizeBuilderExt extension

set the width 92
no setter
w94 → T

Available on T, provided by the SizeBuilderExt extension

set the width 94
no setter
w95 → T

Available on T, provided by the SizeBuilderExt extension

set the width 95
no setter
w96 → T

Available on T, provided by the SizeBuilderExt extension

set the width 96
no setter
w98 → T

Available on T, provided by the SizeBuilderExt extension

set the width 98
no setter
wFull → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width
no setter
wFull10 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*10
no setter
wFull15 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*15
no setter
wFull20 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*20
no setter
wFull25 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*25
no setter
wFull30 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*30
no setter
wFull35 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*35
no setter
wFull40 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*40
no setter
wFull45 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*45
no setter
wFull5 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*5
no setter
wFull50 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*50
no setter
wFull55 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*55
no setter
wFull60 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*60
no setter
wFull65 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*65
no setter
wFull70 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*70
no setter
wFull75 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*75
no setter
wFull80 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*80
no setter
wFull85 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*85
no setter
wFull90 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*90
no setter
wFull95 → T

Available on T, provided by the SizeBuilderExt extension

set the width is screen width*95
no setter
width double?
getter/setter pair
wInfinity → T

Available on T, provided by the SizeBuilderExt extension

no setter

Methods

createSizedBox(Widget child) Widget
h(double? height) → T

Available on T, provided by the SizeBuilderExt extension

set the height
height(double? height) → T

Available on T, provided by the SizeBuilderExt extension

set the height
maxH(double height) → T

Available on T, provided by the SizeBuilderExt extension

set the max height
maxHeight(double height) → T

Available on T, provided by the SizeBuilderExt extension

set the max height
maxW(double width) → T

Available on T, provided by the SizeBuilderExt extension

set the max width
maxWidth(double width) → T

Available on T, provided by the SizeBuilderExt extension

set the max width
minH(double height) → T

Available on T, provided by the SizeBuilderExt extension

set the min height
minHeight(double height) → T

Available on T, provided by the SizeBuilderExt extension

set the min height
minW(double width) → T

Available on T, provided by the SizeBuilderExt extension

set the min width
minWidth(double width) → T

Available on T, provided by the SizeBuilderExt extension

set the min width
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
s(double? size) → T

Available on T, provided by the SizeBuilderExt extension

set the size
size(double? size) → T

Available on T, provided by the SizeBuilderExt extension

set the size
toString() String
A string representation of this object.
inherited
w(double? width) → T

Available on T, provided by the SizeBuilderExt extension

set the width
width(double? width) → T

Available on T, provided by the SizeBuilderExt extension

set the width

Operators

operator ==(Object other) bool
The equality operator.
inherited