sFull50 property
T
get
sFull50
set the width and the width or height is its *50
Implementation
T get sFull50 => this..size = _sFull * .5;
set the width and the width or height is its *50
T get sFull50 => this..size = _sFull * .5;