sFull70 property
T
get
sFull70
set the width and the width or height is its *70
Implementation
T get sFull70 => this..size = _sFull * .7;
set the width and the width or height is its *70
T get sFull70 => this..size = _sFull * .7;