AlignmentBuilder mixin
Barry @date 2024/8/20 describe:
- Mixin applications
- Available extensions
Properties
- alignment ↔ Alignment?
-
getter/setter pair
-
alignments
↔ List<
Alignment> ? -
getter/setter pair
- bottomCenter → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.bottomCenterno setter - bottomLeft → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.bottomLeftno setter - bottomRight → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.bottomRightno setter - center → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.centerno setter - centerLeft → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.centerLeftno setter - centerRight → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.centerRightno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topCenter → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.topCenterno setter - topLeft → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.topLeftno setter - topRight → T
-
Available on T, provided by the AlignmentBuilderExt extension
Alignment.topRightno setter
Methods
-
align(
Alignment? alignment) → T -
Available on T, provided by the AlignmentBuilderExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited