AnimatedCheckBox class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedCheckBox
- Available extensions
Constructors
-
AnimatedCheckBox({Color? color, Color? borderColor, double? width, double? height, double? size, bool value = false, ValueChanged<
bool> ? onChanged, double? borderWidth, BorderRadiusGeometry? borderRadius, bool enableBorder = false, BoxShape shape = BoxShape.rectangle, Widget? icon, bool justIcon = false, bool systemStyle = false, List<BoxShadow> ? boxShadow, double? ratio}) -
const
Properties
- borderColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- borderWidth → double?
-
final
-
boxShadow
→ List<
BoxShadow> ? -
final
- color → Color?
-
final
- enableBorder → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- icon → Widget?
-
final
- justIcon → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
bool> ? -
final
- ratio → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape
-
final
- size → double?
-
final
- systemStyle → bool
-
final
- value → bool
-
final
- width → double?
-
final
Methods
-
click(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _AnimatedCheckBoxState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
iconClick(
{GestureTapCallback? onTap}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
inkWellClick(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited