FontWeightBuilder mixin
- Mixin applications
- Available extensions
Properties
- bold → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.boldno setter - extrabold → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w800no setter - extralight → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w200no setter - fontBlack → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w900no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- innerFontWeight ↔ FontWeight?
-
getter/setter pair
- light → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w300no setter - medium → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w500no setter - normal → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.normalno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semibold → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w600no setter - thin → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w100no setter - w100 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w100no setter - w200 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w200no setter - w300 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w300no setter - w400 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w400no setter - w500 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w500no setter - w600 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w600no setter - w700 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w700no setter - w800 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w800no setter - w900 → T
-
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.w900no setter
Methods
-
fontWeight(
FontWeight? weight) → T -
Available on T, provided by the FontWeightBuilderExt extension
FontWeight weight -
isBold(
bool isBold) → T -
Available on T, provided by the FontWeightBuilderExt extension
FontWeight.bold -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited