Input class
Barry @date 2024/9/11 describe:
- Inheritance
- Available extensions
Constructors
-
Input({Key? key, TextEditingController? controller, Widget? prefixIcon, Widget prefixIconBuilder(bool hasFocus)?, Widget suffixIconBuilder(bool hasFocus)?, Widget visibleWidgetBuilder(bool hasFocus)?, Widget invisibleWidgetBuilder(bool hasFocus)?, Widget? suffixIcon, String? lableText, String? hintText, FocusNode? focusNode, InputBorder? border, bool obscureText = false, EdgeInsetsGeometry? contentPadding, Widget? error, InputBorder? errorBorder, String? errorText, TextStyle? errorStyle, int? errorMaxLines, TextStyle? floatingLabelStyle, FloatingLabelAlignment? floatingLabelAlignment, FloatingLabelBehavior? floatingLabelBehavior, Color? fillColor, Color? unFocusColor, TextInputType? keyboardType, int? maxLines, int? maxLength, int? minLines, bool expands = false, String obscuringCharacter = '•', TextInputAction? textInputAction, TextAlign textAlign = TextAlign.start, bool? enabled, bool enableSuggestions = true, Color? cursorErrorColor, double? cursorHeight, TextCapitalization textCapitalization = TextCapitalization.none, UndoHistoryController? undoController, ValueChanged<
String> ? onChanged, VoidCallback? onEditingComplete, ValueChanged<String> ? onSubmitted, TapRegionCallback? onTapOutside, FocusScopeNode? scopeNode, bool changedDelay = true, List<TextInputFormatter> ? inputFormatters, TextStyle? style, Color? cursorColor, Widget? clearWidget, Widget? visibleWidget, Widget? invisibleWidget}) -
const
-
Input.outline({Key? key, TextEditingController? controller, Widget? prefixIcon, Widget? suffixIcon, Widget prefixIconBuilder(bool hasFocus)?, Widget suffixIconBuilder(bool hasFocus)?, Widget visibleWidgetBuilder(bool hasFocus)?, Widget invisibleWidgetBuilder(bool hasFocus)?, String? lableText, String? hintText, FocusNode? focusNode, bool obscureText = false, EdgeInsetsGeometry? contentPadding, Widget? error, InputBorder? errorBorder, String? errorText, TextStyle? errorStyle, int? errorMaxLines, TextStyle? floatingLabelStyle, FloatingLabelAlignment? floatingLabelAlignment, FloatingLabelBehavior? floatingLabelBehavior, Color? fillColor, Color? unFocusColor, TextInputType? keyboardType, int? maxLines, int? maxLength, int? minLines, bool expands = false, String obscuringCharacter = '•', TextInputAction? textInputAction, TextAlign textAlign = TextAlign.start, bool? enabled, bool enableSuggestions = true, Color? cursorErrorColor, double? cursorHeight, TextCapitalization textCapitalization = TextCapitalization.none, UndoHistoryController? undoController, ValueChanged<
String> ? onChanged, VoidCallback? onEditingComplete, ValueChanged<String> ? onSubmitted, TapRegionCallback? onTapOutside, FocusScopeNode? scopeNode, bool changedDelay = true, List<TextInputFormatter> ? inputFormatters, TextStyle? style, Color? cursorColor, Widget? clearWidget, Widget? visibleWidget, Widget? invisibleWidget}) -
const
Properties
- border → InputBorder?
-
final
- changedDelay → bool
-
final
- clearWidget → Widget?
-
final
- contentPadding → EdgeInsetsGeometry?
-
final
- controller → TextEditingController?
-
final
- cursorColor → Color?
-
final
- cursorErrorColor → Color?
-
final
- cursorHeight → double?
-
final
- enabled → bool?
-
final
- enableSuggestions → bool
-
final
- error → Widget?
-
final
- errorBorder → InputBorder?
-
final
- errorMaxLines → int?
-
final
- errorStyle → TextStyle?
-
final
- errorText → String?
-
final
- expands → bool
-
final
- fillColor → Color?
-
final
- floatingLabelAlignment → FloatingLabelAlignment?
-
final
- floatingLabelBehavior → FloatingLabelBehavior?
-
final
- floatingLabelStyle → TextStyle?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- invisibleWidget → Widget?
-
final
- invisibleWidgetBuilder → Widget Function(bool hasFocus)?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- lableText → String?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- obscureText → bool
-
final
- obscuringCharacter → String
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onEditingComplete → VoidCallback?
-
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- onTapOutside → TapRegionCallback?
-
final
- prefixIcon → Widget?
-
final
- prefixIconBuilder → Widget Function(bool hasFocus)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeNode → FocusScopeNode?
-
final
- style → TextStyle?
-
final
- suffixIcon → Widget?
-
final
- suffixIconBuilder → Widget Function(bool hasFocus)?
-
final
- textAlign → TextAlign
-
final
- textCapitalization → TextCapitalization
-
final
- textInputAction → TextInputAction?
-
final
- undoController → UndoHistoryController?
-
final
- unFocusColor → Color?
-
final
- visibleWidget → Widget?
-
final
- visibleWidgetBuilder → Widget Function(bool hasFocus)?
-
final
Methods
-
click(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _InputState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
iconClick(
{GestureTapCallback? onTap}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
inkWellClick(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress}) → Widget -
Available on Widget, provided by the ClickListenerExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited