WrapMixin mixin
Barry @date 2024/12/9 describe:
- Available extensions
Properties
- alignment ↔ WrapAlignment?
-
getter/setter pair
- center → T
-
Available on T, provided by the WrapMixinExt extension
no setter - crossAxisAlignment ↔ WrapCrossAlignment?
-
getter/setter pair
- crossCenter → T
-
Available on T, provided by the WrapMixinExt extension
no setter - crossEnd → T
-
Available on T, provided by the WrapMixinExt extension
no setter - crossStart → T
-
Available on T, provided by the WrapMixinExt extension
no setter - end → T
-
Available on T, provided by the WrapMixinExt extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runAlignment ↔ WrapAlignment?
-
getter/setter pair
- runCenter → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runEnd → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runSpaceAround → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runSpaceBetween → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runSpaceEvenly → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runStart → T
-
Available on T, provided by the WrapMixinExt extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceAround → T
-
Available on T, provided by the WrapMixinExt extension
no setter - spaceBetween → T
-
Available on T, provided by the WrapMixinExt extension
no setter - spaceEvenly → T
-
Available on T, provided by the WrapMixinExt extension
no setter - start → T
-
Available on T, provided by the WrapMixinExt extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited